pub struct Iam { /* private fields */ }Trait Implementations
Sourceimpl IamService for Iam
Implementation of the IamService trait for the Iam struct.
This implementation provides concrete functionality for all the methods defined in the IamService trait.
By implementing this trait, the Iam struct can be used to interact with the Identity and Access Management (IAM) service,
performing operations such as creating users, managing policies, and handling security configurations.
impl IamService for Iam
Implementation of the IamService trait for the Iam struct.
This implementation provides concrete functionality for all the methods defined in the IamService trait.
By implementing this trait, the Iam struct can be used to interact with the Identity and Access Management (IAM) service,
performing operations such as creating users, managing policies, and handling security configurations.
Sourcefn new_iam(session: Session) -> Result<Self, Error>
fn new_iam(session: Session) -> Result<Self, Error>
new_iam
This method initializes a new IAM service instance with the provided session. It sets up client configuration, client info, and handles, and builds a client for communication with the IAM service.
Parameters
session: The session that will be used to create the IAM service.
Returns
Returns a result containing the new Iam service instance or an error.
Sourceasync fn new_create_user(
&self,
request: CreateUserReq,
) -> Result<CreateUserResp, Error>
async fn new_create_user( &self, request: CreateUserReq, ) -> Result<CreateUserResp, Error>
Sourceasync fn new_get_user(&self, request: GetUserReq) -> Result<GetUserResp, Error>
async fn new_get_user(&self, request: GetUserReq) -> Result<GetUserResp, Error>
Sourceasync fn new_update_user(
&self,
request: UpdateUserReq,
) -> Result<UpdateUserResp, Error>
async fn new_update_user( &self, request: UpdateUserReq, ) -> Result<UpdateUserResp, Error>
Sourceasync fn new_create_login_profile(
&self,
request: CreateLoginProfileReq,
) -> Result<CreateLoginProfileResp, Error>
async fn new_create_login_profile( &self, request: CreateLoginProfileReq, ) -> Result<CreateLoginProfileResp, Error>
Sourceasync fn new_get_login_profile(
&self,
request: GetLoginProfileReq,
) -> Result<GetLoginProfileResp, Error>
async fn new_get_login_profile( &self, request: GetLoginProfileReq, ) -> Result<GetLoginProfileResp, Error>
Sourceasync fn new_update_login_profile(
&self,
request: UpdateLoginProfileReq,
) -> Result<UpdateLoginProfileResp, Error>
async fn new_update_login_profile( &self, request: UpdateLoginProfileReq, ) -> Result<UpdateLoginProfileResp, Error>
Sourceasync fn new_delete_login_profile(
&self,
request: DeleteLoginProfileReq,
) -> Result<DeleteLoginProfileResp, Error>
async fn new_delete_login_profile( &self, request: DeleteLoginProfileReq, ) -> Result<DeleteLoginProfileResp, Error>
Sourceasync fn new_set_security_config(
&self,
request: SetSecurityConfigReq,
) -> Result<SetSecurityConfigResp, Error>
async fn new_set_security_config( &self, request: SetSecurityConfigReq, ) -> Result<SetSecurityConfigResp, Error>
new_set_security_config
This method sets the security configuration for a user in the IAM system.
Parameters
request: The request object containing the details for setting the security configuration.
Returns
Returns a result containing the response object for setting the security configuration or an error.
Sourceasync fn new_get_security_config(
&self,
request: GetSecurityConfigReq,
) -> Result<GetSecurityConfigResp, Error>
async fn new_get_security_config( &self, request: GetSecurityConfigReq, ) -> Result<GetSecurityConfigResp, Error>
Sourceasync fn new_create_project(
&self,
request: CreateProjectReq,
) -> Result<CreateProjectResp, Error>
async fn new_create_project( &self, request: CreateProjectReq, ) -> Result<CreateProjectResp, Error>
Sourceasync fn new_get_project(
&self,
request: GetProjectReq,
) -> Result<GetProjectResp, Error>
async fn new_get_project( &self, request: GetProjectReq, ) -> Result<GetProjectResp, Error>
Sourceasync fn new_create_policy(
&self,
request: CreatePolicyReq,
) -> Result<CreatePolicyResp, Error>
async fn new_create_policy( &self, request: CreatePolicyReq, ) -> Result<CreatePolicyResp, Error>
Sourceasync fn new_get_policy(
&self,
request: GetPolicyReq,
) -> Result<GetPolicyResp, Error>
async fn new_get_policy( &self, request: GetPolicyReq, ) -> Result<GetPolicyResp, Error>
Sourceasync fn new_list_policy(
&self,
request: ListPoliciesReq,
) -> Result<ListPoliciesResp, Error>
async fn new_list_policy( &self, request: ListPoliciesReq, ) -> Result<ListPoliciesResp, Error>
Sourceasync fn new_update_policy(
&self,
request: UpdatePolicyReq,
) -> Result<UpdatePolicyResp, Error>
async fn new_update_policy( &self, request: UpdatePolicyReq, ) -> Result<UpdatePolicyResp, Error>
Sourceasync fn new_delete_policy(
&self,
request: DeletePolicyReq,
) -> Result<DeletePolicyResp, Error>
async fn new_delete_policy( &self, request: DeletePolicyReq, ) -> Result<DeletePolicyResp, Error>
Sourceasync fn new_attach_user_policy(
&self,
request: AttachUserPolicyReq,
) -> Result<AttachUserPolicyResp, Error>
async fn new_attach_user_policy( &self, request: AttachUserPolicyReq, ) -> Result<AttachUserPolicyResp, Error>
Sourceasync fn new_list_attach_user_policy(
&self,
request: ListAttachedUserPoliciesReq,
) -> Result<ListAttachedUserPoliciesResp, Error>
async fn new_list_attach_user_policy( &self, request: ListAttachedUserPoliciesReq, ) -> Result<ListAttachedUserPoliciesResp, Error>
new_list_attach_user_policy
Parameters
&selfrequest: AListAttachedUserPoliciesReqstructure fromvolcengine_sdk_protobuf::protobuf::iam_policy
Returns
- On success, returns a
ListAttachedUserPoliciesRespstructure fromvolcengine_sdk_protobuf::protobuf::iam_policy - On failure, returns an
error::Error
Sourceasync fn new_detach_user_policy(
&self,
request: DetachUserPolicyReq,
) -> Result<DetachUserPolicyResp, Error>
async fn new_detach_user_policy( &self, request: DetachUserPolicyReq, ) -> Result<DetachUserPolicyResp, Error>
Sourceasync fn new_delete_user(
&self,
request: DeleteUserReq,
) -> Result<DeleteUserResp, Error>
async fn new_delete_user( &self, request: DeleteUserReq, ) -> Result<DeleteUserResp, Error>