pub struct Operation {
pub name: OperationName,
pub http_method: OperationHttpMethod,
pub http_path: OperationHttpPath,
}Expand description
Represents an HTTP operation with a name, HTTP method, and HTTP path.
Fields
name: OperationNamehttp_method: OperationHttpMethodhttp_path: OperationHttpPathImplementations
Sourceimpl Operation
impl Operation
Sourcepub fn builder() -> OperationBuilder
pub fn builder() -> OperationBuilder
Provides a builder to construct an Operation instance step by step.
This method returns a new OperationBuilder object. The builder pattern allows for
gradual construction of the Operation object, with flexibility to set each field
individually and validate them before finalizing the construction.
Returns
A new OperationBuilder to build the Operation object.