Module operation_http_method

Module operation_http_method 

Enums

OperationHttpMethod
Enum representing possible HTTP methods that can be used in API operations. This enum provides a type - safe way to specify the HTTP method for an API request. It currently includes the two most commonly used HTTP methods: GET and POST. The Debug derive allows for easy debugging by providing a default implementation of the fmt::Debug trait, which enables printing the enum variants in a readable format. The Clone derive allows for creating copies of the enum values when needed.