Module send

Module send 

Structs

Send
Represents a Send struct used for handling an API request.

Traits

SendRequest
Trait for handling the creation, signing, and sending of API requests. Provides methods for building request headers, signing them, and sending requests.