Structs
- Send
- Represents a
Sendstruct used for handling an API request.
Traits
- Send
Request - Trait for handling the creation, signing, and sending of API requests. Provides methods for building request headers, signing them, and sending requests.
Send struct used for handling an API request.